@@ -117,7 +117,7 @@ class Extractor(QtCore.QObject):
          self.parsePerturbation =  True
          request = QNetworkRequest( QtCore.QUrl( urlPerturbation ) )
          self.manager.get(request)
-         
+
       if error:
          self.rideModel.SetInfo('ERROR', error)
 
@@ -127,7 +127,8 @@ class Extractor(QtCore.QObject):
       res = re.findall('<div id="icv".+?>(.+?)</div>', str, re.DOTALL)
       if res:
          for perturbation in res:
-            self.rideModel.AddPerturbation( perturbation.strip().replace('&#39;', "'") )
+            p = re.sub('\s+', ' ',perturbation).strip().replace('&#39;', "'")
+            self.rideModel.AddPerturbation(p)
 
 
    def AppendRidesToModel(self, imax):
