@@ -11,25 +11,6 @@ from extractors.ExtractorTransilien import ExtractorTransilien
 from extractors.ExtractorMetroMobi import ExtractorMetro
 from extractors.ExtractorRERratp import ExtractorRERratp
 
-class CellModel:
-   def __init__(self):
-      self.data = dict()
-      self.data[Qt.FontRole] = QVariant()
-      self.data[Qt.DisplayRole] = ''
-      self.data[Qt.DecorationRole] = QVariant()
-      self.data[Qt.BackgroundRole] = QVariant()
-      self.data[Qt.ForegroundRole] = QVariant()
-      self.data[Qt.TextAlignmentRole] = QVariant( Qt.AlignCenter|Qt.AlignVCenter )
-
-   def __getitem__(self, item):
-      try:
-         return self.data[item]
-      except KeyError:
-         return QVariant()
-
-   def __setitem__(self, item, val):
-      self.data[item] = val
-
 class TrainTrainModel(QAbstractTableModel):
    def __init__(self):
       QAbstractTableModel.__init__(self)
@@ -48,8 +29,11 @@ class TrainTrainModel(QAbstractTableModel):
       self.db = DbTrain()
       self.gareMgr = GareManager(self.db)
       self.online = True
-      t = TrainTrainConf()
-      self.max = t.nbTrains()
+      self.ttConf = TrainTrainConf()
+      self.max = self.ttConf.nbTrains()
+
+   def ReadConfig(self):
+      self.ttConf.ReadConfig()
 
    def GetRidesModel(self):
       return [self.rides[k] for k in sorted(self.rides.keys())]
@@ -111,7 +95,7 @@ class TrainTrainModel(QAbstractTableModel):
    def Extracted(self, rideModel):
       self.emit(QtCore.SIGNAL('extracted'), rideModel)
 
-   def RefreshDatas(self, id=None):
+   def RefreshDatas(self, id=''):
       DebugLog("TrainTrainModel::RefreshDatas")
       if id:
          self.rideList[id].FetchDatas(self, self.max)
