@@ -138,6 +138,7 @@ class TrainTrainConf:
 
    def ReadConfig(self):
       self.nb = 2
+      self.refreshrate = '1 min'
       if os.path.exists(self.conf):
          t = ConfigParser()
          t.read(self.conf)
@@ -145,16 +146,42 @@ class TrainTrainConf:
             self.nb = int(t.get('trajets', 'nbtrains'))
          except:
             pass
+         try:
+            self.refreshrate = t.get('trajets', 'refreshrate')
+         except:
+            pass
       else:
-         self.WriteConfig(self.nb)
+         self.WriteConfig()
 
-   def WriteConfig(self, nb):
+   def SetNbTrains(self, nb):
+      self.nb = nb
+
+   def SetRefreshRate(self, rr):
+      self.refreshrate = rr
+
+   def WriteConfig(self):
       f = open(self.conf, 'w')
       t = ConfigParser()
 
       t.add_section('trajets')
-      t.set('trajets', 'nbtrains', nb)
+      t.set('trajets', 'nbtrains', self.nb)
+      t.set('trajets', 'refreshrate', self.refreshrate)
       t.write(f)
 
    def nbTrains(self):
       return self.nb
+
+   def refreshRate(self):
+      return self.refreshrate
+
+   def refreshRateSec(self):
+      r=self.refreshrate
+      if r=='15 s':
+         return 15
+      if r=='30 s':
+         return 30
+      if r=='1 min':
+         return 60
+      if r=='5 min':
+         return 300
+
