@@ -19,6 +19,8 @@ class RideView(QtGui.QWidget):
       self.model = model
       self.connect(self.model, QtCore.SIGNAL("progress"), self.updateBar)
       self.connect(self.model, QtCore.SIGNAL("info"), self.SetInfo)
+      self.timer = QtCore.QTimer()
+      self.connect(self.timer, QtCore.SIGNAL("timeout()"), self.Refresh)
       self.PrepareWidget()
 
       self.animate = QtCore.QPropertyAnimation(self.progress, "size", self)
@@ -129,8 +131,11 @@ class RideView(QtGui.QWidget):
       title.setStyleSheet("QPushButton { background: #fff; padding:10px; color: #194F97; text-align:left; border: none } ")
       menu = QtGui.QMenu(title)
       refreshAction = menu.addAction('Rafraichir')
+      refreshAutoAction = menu.addAction('Rafraichissement auto')
+      refreshAutoAction.setCheckable(True)
       removeAction = menu.addAction('Supprimer ce trajet')
       QtCore.QObject.connect(refreshAction, QtCore.SIGNAL("triggered()"), self.Refresh)
+      QtCore.QObject.connect(refreshAutoAction, QtCore.SIGNAL("triggered()"), self.RefreshAuto)
       QtCore.QObject.connect(removeAction, QtCore.SIGNAL("triggered()"), self.Remove)
       title.setMenu(menu)
       layoutTitle.addWidget(title)
@@ -157,6 +162,13 @@ class RideView(QtGui.QWidget):
       self.Busy()
       self.parent.model.RefreshDatas(self.model.id)
 
+   def RefreshAuto(self):
+      if self.timer.isActive():
+         self.timer.stop()
+      else:
+         self.timer.setInterval(self.parent.model.ttConf.refreshRateSec()*1000)
+         self.timer.start()
+
    def UpdateRides(self):
       DebugLog("RideView::UpdateRides")
       irow=2
