@@ -9,6 +9,7 @@ from model.TrainTrainModel import TrainTrainModel
 from view.RideView import RideView
 from view.SettingsDlg import SettingsDlg
 from view.AddRide import AddRideDlg
+import version
 
 class TrainTrainView(QtGui.QMainWindow):
 
@@ -37,6 +38,8 @@ class TrainTrainView(QtGui.QMainWindow):
       self.model = TrainTrainModel()
       self.model.SetOnline(True)
       self.views = dict()
+      self.timer = QtCore.QTimer()
+      self.connect(self.timer, QtCore.SIGNAL("timeout()"), self.Refresh)
 
       self.CreateAppLayouts()
       self.ReInit()
@@ -54,6 +57,8 @@ class TrainTrainView(QtGui.QMainWindow):
    def Settings(self):
       dlg = SettingsDlg()
       dlg.exec_()
+      self.model.ReadConfig()
+      self.timer.setInterval(self.model.ttConf.refreshRateSec()*1000)
 
    def AddRide(self):
       dlg = AddRideDlg(self.model.garesConf)
@@ -90,7 +95,12 @@ class TrainTrainView(QtGui.QMainWindow):
 
       update = QtGui.QAction(u'Rafraîchir', self)
       update.setShortcut('Ctrl+R')
-      self.connect(update, QtCore.SIGNAL('triggered()'), self.Update)
+      self.connect(update, QtCore.SIGNAL('triggered()'), self.Refresh)
+
+      updateauto = QtGui.QAction(u'Rafraîchissement auto', self)
+      updateauto.setShortcut('Ctrl+B')
+      updateauto.setCheckable(True)
+      self.connect(updateauto, QtCore.SIGNAL('triggered()'), self.RefreshAuto)
 
       settings = QtGui.QAction(u'Paramètres', self)
       settings.setShortcut('Ctrl+O')
@@ -103,6 +113,7 @@ class TrainTrainView(QtGui.QMainWindow):
       file = menubar.addMenu('&Options')
       file.addAction(add)
       file.addAction(update)
+      file.addAction(updateauto)
       file.addAction(settings)
       file.addAction(about)
 
@@ -150,14 +161,24 @@ class TrainTrainView(QtGui.QMainWindow):
       else:
          self.tabW.setTabPosition(QtGui.QTabWidget.South)
 
-   def Update(self):
-      DebugLog("TrainTrainView::Update")
+   def Refresh(self):
+      DebugLog("TrainTrainView::Refresh")
       self.updateCpt=0
       self.SetLoading(True)
 
-      for view in self.views.values():
-         view.Busy()
-      self.model.RefreshDatas()
+      if self.refreshId:
+         self.views[self.refreshId].Refresh()
+      else:
+         for view in self.views.values():
+            view.Busy()
+         self.model.RefreshDatas()
+
+   def RefreshAuto(self):
+      if self.timer.isActive():
+         self.timer.stop()
+      else:
+         self.timer.setInterval(self.model.ttConf.refreshRateSec()*1000)
+         self.timer.start()
 
    def Extracted(self, rideModel):
       DebugLog("TrainTrainView::Extracted")
@@ -175,7 +196,9 @@ class TrainTrainView(QtGui.QMainWindow):
          pass
 
    def About(self):
-      QtGui.QMessageBox.about(self, "A propos", u'TrainTrain\nDéveloppé par Gérald Fauvelle\nhttp://projects.forum.nokia.com/TrainTrain')
+      v = version.appVersion
+      QtGui.QMessageBox.about(self, "A propos",
+      u'TrainTrain %s\nDéveloppé par Gérald Fauvelle\nhttp://projects.forum.nokia.com/TrainTrain'%v)
       return
 
    def closeEvent(self, event):
